tlslite.utils.Cryptlib_TripleDES.Cryptlib_TripleDES

Package tlslite :: Package utils :: Module Cryptlib_TripleDES :: Class Cryptlib_TripleDES |
[show private | hide private]
[frames | no frames]

## Class Cryptlib_TripleDES

    TripleDES --+
                |
               Cryptlib_TripleDES

Method Summary
| `__init__(self, key, mode, IV)`
| `__del__(self)`
| `decrypt(self, ciphertext)`
| `encrypt(self, plaintext)`

Generated by Epydoc 2.0 on Mon Feb 21 21:56:53 2005 | http://epydoc.sf.net